import os
from typing import Any

from pydantic import Field

from compose.container import BaseModel


class GunicornSettings(BaseModel):
    wsgi_app: str
    bind: str = "0.0.0.0:80"
    workers: int = Field(default_factory=lambda: os.cpu_count() + 1)
    worker_class: str = "uvicorn.UvicornWorker"
    threads: int = 2
    timeout: int = 120
    max_requests: int | None = None
    max_requests_jitter: int | None = None


def export_settings(
    globals_: dict[str, Any],
    settings: GunicornSettings,
    **kwargs,
) -> None:
    globals_ |= settings.model_dump(exclude_none=True) | kwargs



from .container import DeclarativeContainer
from .provider import factory_of_factory
from .wiring import (
    DEFAULT_RESOLVABLE_PROVIDER_TYPES,
    ConflictResolution,
    create_provider,
    create_wirer,
    get_wiring_packages,
    provide,
    resolve,
    resolve_by_object_name,
)

__all__ = [
    "DEFAULT_RESOLVABLE_PROVIDER_TYPES",
    "ConflictResolution",
    "DeclarativeContainer",
    "create_provider",
    "create_wirer",
    "factory_of_factory",
    "get_wiring_packages",
    "provide",
    "resolve",
    "resolve_by_object_name",
]
